searchData={"items":[{"type":"task","title":"mix trogon.type_provider.list","doc":"Lists all registered type mappings for a given TypeProvider module.","ref":"Mix.Tasks.Trogon.TypeProvider.List.html"},{"type":"task","title":"Usage - mix trogon.type_provider.list","doc":"mix trogon.type_provider.list TypeProvider","ref":"Mix.Tasks.Trogon.TypeProvider.List.html#module-usage"},{"type":"task","title":"Examples - mix trogon.type_provider.list","doc":"# List all types in a specific provider\n    mix trogon.type_provider.list MyApp.EventTypeProvider","ref":"Mix.Tasks.Trogon.TypeProvider.List.html#module-examples"},{"type":"module","title":"Trogon.TypeProvider","doc":"Provides a type mapping system for converting between string type names and Elixir struct modules.","ref":"Trogon.TypeProvider.html"},{"type":"macro","title":"Trogon.TypeProvider.import_type_provider/1","doc":"Imports all the types from another module defined by `Trogon.TypeProvider`.","ref":"Trogon.TypeProvider.html#import_type_provider/1"},{"type":"macro","title":"Example - Trogon.TypeProvider.import_type_provider/1","doc":"defmodule UserTypeProvider do\n      use Trogon.TypeProvider\n      # ...\n    end\n\n    defmodule MyAppTypeProvider do\n      use Trogon.TypeProvider\n\n      import_type_provider UserTypeProvider\n    end","ref":"Trogon.TypeProvider.html#import_type_provider/1-example"},{"type":"macro","title":"Trogon.TypeProvider.register_type/2","doc":"Registers a mapping from a type string to an Elixir Module that defines a struct.","ref":"Trogon.TypeProvider.html#register_type/2"},{"type":"macro","title":"Example - Trogon.TypeProvider.register_type/2","doc":"defmodule MyTypeProvider do\n      use Trogon.TypeProvider,\n        prefix: \"accounts.\" # optional, adds the prefix to the type\n\n      register_type \"account_created\", AccountCreated\n    end","ref":"Trogon.TypeProvider.html#register_type/2-example"},{"type":"exception","title":"Trogon.TypeProvider.UnregisteredMappingError","doc":"Exception raised when attempting to access an unregistered type mapping in a TypeProvider.\n\nThis exception provides detailed information about the failed lookup,\nincluding the mapping that was requested and the TypeProvider that was consulted.","ref":"Trogon.TypeProvider.UnregisteredMappingError.html"},{"type":"type","title":"Trogon.TypeProvider.UnregisteredMappingError.t/0","doc":"","ref":"Trogon.TypeProvider.UnregisteredMappingError.html#t:t/0"},{"type":"extras","title":"Trogon.TypeProvider","doc":"# Trogon.TypeProvider\n\n**A compile-time type mapping system that converts between string type names and Elixir struct modules with zero\nruntime overhead.**\n\n**`Trogon.TypeProvider` generates efficient pattern-matching functions at compile time to bidirectionally map string\nidentifiers to Elixir structs**. It provides a clean tuple-based API that returns `{:ok, result}` for successful mappings\nand `{:error, error}` for failures, ensuring predictable error handling throughout your application.\n\n**This solves the common need for type serialization and deserialization in event-driven architectures, message queues,\nand data persistence layers**. Instead of maintaining manual mapping logic or runtime lookups, `Trogon.TypeProvider`\nautomatically generates optimized functions that handle the conversion between human-readable type names and your\napplication's struct modules.\n\n**`Trogon.TypeProvider` is particularly useful for developers building event sourcing systems, CQRS applications, or\nany system that needs to serialize domain events and commands**. It's ideal for teams working with Commanded,\nEventStore, or custom event-driven architectures where type safety and performance are critical requirements.","ref":"readme.html"},{"type":"extras","title":"Usage - Trogon.TypeProvider","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic TypeProvider - Trogon.TypeProvider","doc":"```elixir\ndefmodule MyApp.TypeProvider do\n  use Trogon.TypeProvider\n\n  # Register individual types\n  register_type \"user_created\", MyApp.UserCreated\n  register_type \"user_updated\", MyApp.UserUpdated\n  register_type \"user_deleted\", MyApp.UserDeleted\nend\n```","ref":"readme.html#basic-typeprovider"},{"type":"extras","title":"TypeProvider with Prefix - Trogon.TypeProvider","doc":"```elixir\ndefmodule MyApp.AccountTypeProvider do\n  use Trogon.TypeProvider, prefix: \"accounts.\"\n\n  register_type \"created\", MyApp.AccountCreated\n  register_type \"updated\", MyApp.AccountUpdated\n  # Results in types: \"accounts.created\", \"accounts.updated\"\nend\n```","ref":"readme.html#typeprovider-with-prefix"},{"type":"extras","title":"Importing from Other TypeProviders - Trogon.TypeProvider","doc":"```elixir\ndefmodule MyApp.GlobalTypeProvider do\n  use Trogon.TypeProvider\n\n  # Import all types from other providers\n  import_type_provider MyApp.UserTypeProvider\n  import_type_provider MyApp.AccountTypeProvider\n\n  # Add additional types\n  register_type \"system_started\", MyApp.Events.SystemStarted\nend\n```","ref":"readme.html#importing-from-other-typeproviders"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [0.2.2](https://github.com/straw-hat-team/beam-monorepo/compare/trogon_typeprovider@v0.2.1...trogon_typeprovider@v0.2.2) (2025-07-08)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **trogon_typeprovider:** Improve struct detection for embedded schemas ([#222](https://github.com/straw-hat-team/beam-monorepo/issues/222)) ([96fc99f](https://github.com/straw-hat-team/beam-monorepo/commit/96fc99fc0608e7a318f7d4318df764de25408b0e))\n\n## [0.2.1](https://github.com/straw-hat-team/beam-monorepo/compare/trogon_typeprovider@v0.2.0...trogon_typeprovider@v0.2.1) (2025-07-08)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **trogon_typeprovider:** Ensure compiled code ([#219](https://github.com/straw-hat-team/beam-monorepo/issues/219)) ([6552b51](https://github.com/straw-hat-team/beam-monorepo/commit/6552b51b921f3175ac54692c047eb4a2f6c02bbf))\n\n## [0.2.0](https://github.com/straw-hat-team/beam-monorepo/compare/trogon_typeprovider@v0.1.0...trogon_typeprovider@v0.2.0) (2025-07-08)","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"Features - Changelog","doc":"* **trogon_typeprovider:** Create the trogon typeprovider pkg ([#217](https://github.com/straw-hat-team/beam-monorepo/issues/217)) ([03649cb](https://github.com/straw-hat-team/beam-monorepo/commit/03649cb206638b578c98705c1e88cc4c6d0c6525))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}